@@ -30,7 +30,7 @@
 
 using namespace KScreen;
 
-class Output::Private
+class Q_DECL_HIDDEN Output::Private
 {
   public:
     Private():
@@ -553,7 +553,6 @@ void Output::apply(const OutputPtr& other)
     }
     if (!d->compareModeList(d->modeList, other->d->modeList)) {
         changes << &Output::outputChanged;
-        changes << &Output::modesChanged;
     }
 
     setPreferredModes(other->d->preferredModes);
